@@ -2,7 +2,7 @@ package Mew;
 
 use strictures 2;
 
-our $VERSION = '1.002002'; # VERSION
+our $VERSION = '1.002003'; # VERSION
 
 use Import::Into;
 use Moo;
@@ -26,11 +26,13 @@ sub import {
         my $req = 1;
         my $mew_type;
         $mew_type = shift if @_ % 2 != 0;
-        if ($mew_type and $mew_type->is_parameterized and $mew_type->parent == Types::Standard::Optional()) {
+        if ($mew_type and $mew_type->is_parameterized
+          and $mew_type->parent->strictly_equals(Types::Standard::Optional())) {
             $req = 0;
             $mew_type = $mew_type->type_parameter;
         }
-        elsif ($mew_type and $mew_type == Types::Standard::Optional()) {
+        elsif ($mew_type
+          and $mew_type->strictly_equals(Types::Standard::Optional())) {
             $req = 0;
             $mew_type = Types::Standard::Any();
         }
@@ -308,4 +310,4 @@ You can use and distribute this module under the same terms as Perl itself.
 See the C<LICENSE> file included in this distribution for complete
 details.
 
-=cut
\ No newline at end of file
+=cut
